@@ -1,7 +1,8 @@
 import settings as sfs_settings
 import models
 from django.core.urlresolvers import reverse
-from django.http import HttpResponseForbidden
+from django.shortcuts import render
+from django.utils import ipv6
 
 class StopForumSpamMiddleware():
 
@@ -13,7 +14,7 @@ class StopForumSpamMiddleware():
         def compile_paths(path_list):
             paths = []
             for path in path_list:
-                if path.starts_with("/"):
+                if path.startswith("/"):
                     paths.append(path)
                 else:
                     paths.append(reverse(path))
@@ -32,11 +33,15 @@ class StopForumSpamMiddleware():
     
     def check_request_ip(self, request):
         
-        remote_ip = request.META['REMOTE_ADDR']
+        remote_ip = ipv6._unpack_ipv4(request.META['REMOTE_ADDR'])
         
-        if models.Cache.objects.filter(ip=remote_ip).count() > 0:
+        cache_entries = models.Cache.objects.filter(ip=remote_ip)
+        
+        if cache_entries.count() > 0:
             if sfs_settings.LOG_SPAM:
                 log = models.Log(message = "Spam received from %s" % remote_ip)
                 log.save()
-            return HttpResponseForbidden("Goodbye, spammer")
+            
+            return render(request, 'stopforumspam/denied.html', {"cache_entries": cache_entries,},
+                          status=403)
     
